containertools.insert_component_and_fracture_crossing_spanners
==============================================================

.. autofunction:: abjad.tools.containertools.insert_component_and_fracture_crossing_spanners.insert_component_and_fracture_crossing_spanners
